@@ -10,6 +10,9 @@ PORTICUS_GALLERY_TEMPLATE_CHOICES = (
 PORTICUS_ALBUM_TEMPLATE_CHOICES = (
     ('porticus/album_detail.html', 'Default template'),
 )
+PORTICUS_GALLERY_PLUGIN_TEMPLATE_CHOICES = (
+    ('porticus/cms/gallery_detail.html', 'Default template'),
+)
 PORTICUS_ALBUM_PLUGIN_TEMPLATE_CHOICES = (
     ('porticus/cms/album_detail.html', 'Default template'),
 )
@@ -17,6 +20,7 @@ PORTICUS_ALBUM_PLUGIN_TEMPLATE_CHOICES = (
 # Default template choices
 PORTICUS_GALLERY_TEMPLATE_DEFAULT = PORTICUS_GALLERY_TEMPLATE_CHOICES[0][0]
 PORTICUS_ALBUM_TEMPLATE_DEFAULT = PORTICUS_ALBUM_TEMPLATE_CHOICES[0][0]
+PORTICUS_GALLERY_PLUGIN_TEMPLATE_DEFAULT = PORTICUS_GALLERY_PLUGIN_TEMPLATE_CHOICES[0][0]
 PORTICUS_ALBUM_PLUGIN_TEMPLATE_DEFAULT = PORTICUS_ALBUM_PLUGIN_TEMPLATE_CHOICES[0][0]
 
 # Templates for templatetags
